@@ -1346,10 +1346,16 @@ class Nv(epyqlib.canneo.Signal, TreeNode):
         return self.factory
 
     def is_read_only(self):
-        return self.frame.read_write.min > 0 or self.is_summary
+        if self.rw is None:
+            return self.frame.read_write.min > 0 or self.is_summary
+
+        return self.rw.readable and not self.rw.writable
 
     def is_write_only(self):
-        return self.frame.read_write.max < 1
+        if self.rw is None:
+            return self.frame.read_write.max < 1
+
+        return self.rw.writable and not self.rw.readable
 
     def unique(self):
         # TODO: make it more unique
@@ -1843,6 +1849,72 @@ class NvModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
 
             self.activity_ended.emit(message)
 
+    @pyqtSlot()
+    def write_to_overlay_value_set_file(self, parent=None):
+        fields = attr.fields(epyqlib.pm.valuesetmodel.ValueSet)
+        filters = fields.filters.default
+
+        reference_path = epyqlib.utils.qt.file_dialog(
+            caption='Overlay Reference File',
+            filters=filters,
+            save=False,
+            parent=parent,
+        )
+
+        if reference_path is None:
+            return
+
+        reference_value_set = epyqlib.pm.valuesetmodel.loadp(reference_path)
+
+        save_path = epyqlib.utils.qt.file_dialog(
+            caption='Overlay File',
+            filters=filters,
+            save=True,
+            parent=parent,
+        )
+
+        if save_path is None:
+            return
+
+        complete_value_set = self.root.to_value_set()
+        complete_value_set.path = save_path
+
+        reference_parameter_by_uuid = {
+            parameter.parameter_uuid: parameter
+            for parameter in reference_value_set.model.root.children
+        }
+
+        drop_list = []
+
+        for output_parameter in complete_value_set.model.root.children:
+            reference_parameter = reference_parameter_by_uuid.get(
+                output_parameter.parameter_uuid,
+            )
+            if reference_parameter is None:
+                continue
+
+            if not output_parameter.writable:
+                drop_list.append(output_parameter)
+                continue
+
+            for meta in MetaEnum.non_value:
+                setattr(output_parameter, meta.name, None)
+
+            if reference_parameter.value == output_parameter.value:
+                drop_list.append(output_parameter)
+
+        for parameter in drop_list:
+            complete_value_set.model.root.remove_child(child=parameter)
+
+        try:
+            complete_value_set.save()
+        except epyqlib.pm.valuesetmodel.SaveCancelled:
+            message = 'Save cancelled'
+        else:
+            message = 'Saved to "{}"'.format(complete_value_set.path)
+
+        self.activity_ended.emit(message)
+
     @pyqtSlot()
     def read_from_file(self, parent=None):
         filters = [
